userdepartment

package
v0.0.0-...-f8e2896 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 9, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the userdepartment type in the database.
	Label = "user_department"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldDeptID holds the string denoting the dept_id field in the database.
	FieldDeptID = "dept_id"
	// FieldTenantID holds the string denoting the tenant_id field in the database.
	FieldTenantID = "tenant_id"
	// FieldAttributes holds the string denoting the attributes field in the database.
	FieldAttributes = "attributes"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// EdgeDepartment holds the string denoting the department edge name in mutations.
	EdgeDepartment = "department"
	// Table holds the table name of the userdepartment in the database.
	Table = "user_departments"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "user_departments"
	// UserInverseTable is the table name for the User entity.
	// It exists in this package in order to avoid circular dependency with the "user" package.
	UserInverseTable = "users"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_id"
	// DepartmentTable is the table that holds the department relation/edge.
	DepartmentTable = "user_departments"
	// DepartmentInverseTable is the table name for the Department entity.
	// It exists in this package in order to avoid circular dependency with the "department" package.
	DepartmentInverseTable = "departments"
	// DepartmentColumn is the table column denoting the department relation/edge.
	DepartmentColumn = "dept_id"
)

Variables

Columns holds all SQL columns for userdepartment fields.

var (
	// DefaultAttributes holds the default value on creation for the "attributes" field.
	DefaultAttributes map[string]interface{}
)

Functions

func And

And groups predicates with the AND operator between them.

func DeptID

func DeptID(v int64) predicate.UserDepartment

DeptID applies equality check predicate on the "dept_id" field. It's identical to DeptIDEQ.

func DeptIDEQ

func DeptIDEQ(v int64) predicate.UserDepartment

DeptIDEQ applies the EQ predicate on the "dept_id" field.

func DeptIDIn

func DeptIDIn(vs ...int64) predicate.UserDepartment

DeptIDIn applies the In predicate on the "dept_id" field.

func DeptIDNEQ

func DeptIDNEQ(v int64) predicate.UserDepartment

DeptIDNEQ applies the NEQ predicate on the "dept_id" field.

func DeptIDNotIn

func DeptIDNotIn(vs ...int64) predicate.UserDepartment

DeptIDNotIn applies the NotIn predicate on the "dept_id" field.

func HasDepartment

func HasDepartment() predicate.UserDepartment

HasDepartment applies the HasEdge predicate on the "department" edge.

func HasDepartmentWith

func HasDepartmentWith(preds ...predicate.Department) predicate.UserDepartment

HasDepartmentWith applies the HasEdge predicate on the "department" edge with a given conditions (other predicates).

func HasUser

func HasUser() predicate.UserDepartment

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.User) predicate.UserDepartment

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.UserDepartment

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.UserDepartment

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.UserDepartment

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.UserDepartment

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.UserDepartment

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.UserDepartment

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.UserDepartment

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.UserDepartment

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func TenantID

func TenantID(v int64) predicate.UserDepartment

TenantID applies equality check predicate on the "tenant_id" field. It's identical to TenantIDEQ.

func TenantIDEQ

func TenantIDEQ(v int64) predicate.UserDepartment

TenantIDEQ applies the EQ predicate on the "tenant_id" field.

func TenantIDGT

func TenantIDGT(v int64) predicate.UserDepartment

TenantIDGT applies the GT predicate on the "tenant_id" field.

func TenantIDGTE

func TenantIDGTE(v int64) predicate.UserDepartment

TenantIDGTE applies the GTE predicate on the "tenant_id" field.

func TenantIDIn

func TenantIDIn(vs ...int64) predicate.UserDepartment

TenantIDIn applies the In predicate on the "tenant_id" field.

func TenantIDLT

func TenantIDLT(v int64) predicate.UserDepartment

TenantIDLT applies the LT predicate on the "tenant_id" field.

func TenantIDLTE

func TenantIDLTE(v int64) predicate.UserDepartment

TenantIDLTE applies the LTE predicate on the "tenant_id" field.

func TenantIDNEQ

func TenantIDNEQ(v int64) predicate.UserDepartment

TenantIDNEQ applies the NEQ predicate on the "tenant_id" field.

func TenantIDNotIn

func TenantIDNotIn(vs ...int64) predicate.UserDepartment

TenantIDNotIn applies the NotIn predicate on the "tenant_id" field.

func UserID

func UserID(v int64) predicate.UserDepartment

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

func UserIDEQ(v int64) predicate.UserDepartment

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...int64) predicate.UserDepartment

UserIDIn applies the In predicate on the "user_id" field.

func UserIDNEQ

func UserIDNEQ(v int64) predicate.UserDepartment

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...int64) predicate.UserDepartment

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the UserDepartment queries.

func ByDepartmentField

func ByDepartmentField(field string, opts ...sql.OrderTermOption) OrderOption

ByDepartmentField orders the results by department field.

func ByDeptID

func ByDeptID(opts ...sql.OrderTermOption) OrderOption

ByDeptID orders the results by the dept_id field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByTenantID

func ByTenantID(opts ...sql.OrderTermOption) OrderOption

ByTenantID orders the results by the tenant_id field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to