Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Department) predicate.Department
- func CreatedAt(v time.Time) predicate.Department
- func CreatedAtEQ(v time.Time) predicate.Department
- func CreatedAtGT(v time.Time) predicate.Department
- func CreatedAtGTE(v time.Time) predicate.Department
- func CreatedAtIn(vs ...time.Time) predicate.Department
- func CreatedAtLT(v time.Time) predicate.Department
- func CreatedAtLTE(v time.Time) predicate.Department
- func CreatedAtNEQ(v time.Time) predicate.Department
- func CreatedAtNotIn(vs ...time.Time) predicate.Department
- func CreatedBy(v int64) predicate.Department
- func CreatedByEQ(v int64) predicate.Department
- func CreatedByGT(v int64) predicate.Department
- func CreatedByGTE(v int64) predicate.Department
- func CreatedByIn(vs ...int64) predicate.Department
- func CreatedByIsNil() predicate.Department
- func CreatedByLT(v int64) predicate.Department
- func CreatedByLTE(v int64) predicate.Department
- func CreatedByNEQ(v int64) predicate.Department
- func CreatedByNotIn(vs ...int64) predicate.Department
- func CreatedByNotNil() predicate.Department
- func DeletedAt(v time.Time) predicate.Department
- func DeletedAtEQ(v time.Time) predicate.Department
- func DeletedAtGT(v time.Time) predicate.Department
- func DeletedAtGTE(v time.Time) predicate.Department
- func DeletedAtIn(vs ...time.Time) predicate.Department
- func DeletedAtIsNil() predicate.Department
- func DeletedAtLT(v time.Time) predicate.Department
- func DeletedAtLTE(v time.Time) predicate.Department
- func DeletedAtNEQ(v time.Time) predicate.Department
- func DeletedAtNotIn(vs ...time.Time) predicate.Department
- func DeletedAtNotNil() predicate.Department
- func HasTenant() predicate.Department
- func HasTenantWith(preds ...predicate.Tenant) predicate.Department
- func HasUserDepartments() predicate.Department
- func HasUserDepartmentsWith(preds ...predicate.UserDepartment) predicate.Department
- func ID(id int64) predicate.Department
- func IDEQ(id int64) predicate.Department
- func IDGT(id int64) predicate.Department
- func IDGTE(id int64) predicate.Department
- func IDIn(ids ...int64) predicate.Department
- func IDLT(id int64) predicate.Department
- func IDLTE(id int64) predicate.Department
- func IDNEQ(id int64) predicate.Department
- func IDNotIn(ids ...int64) predicate.Department
- func Name(v string) predicate.Department
- func NameContains(v string) predicate.Department
- func NameContainsFold(v string) predicate.Department
- func NameEQ(v string) predicate.Department
- func NameEqualFold(v string) predicate.Department
- func NameGT(v string) predicate.Department
- func NameGTE(v string) predicate.Department
- func NameHasPrefix(v string) predicate.Department
- func NameHasSuffix(v string) predicate.Department
- func NameIn(vs ...string) predicate.Department
- func NameLT(v string) predicate.Department
- func NameLTE(v string) predicate.Department
- func NameNEQ(v string) predicate.Department
- func NameNotIn(vs ...string) predicate.Department
- func Not(p predicate.Department) predicate.Department
- func Or(predicates ...predicate.Department) predicate.Department
- func ParentID(v int64) predicate.Department
- func ParentIDEQ(v int64) predicate.Department
- func ParentIDGT(v int64) predicate.Department
- func ParentIDGTE(v int64) predicate.Department
- func ParentIDIn(vs ...int64) predicate.Department
- func ParentIDLT(v int64) predicate.Department
- func ParentIDLTE(v int64) predicate.Department
- func ParentIDNEQ(v int64) predicate.Department
- func ParentIDNotIn(vs ...int64) predicate.Department
- func Path(v string) predicate.Department
- func PathContains(v string) predicate.Department
- func PathContainsFold(v string) predicate.Department
- func PathEQ(v string) predicate.Department
- func PathEqualFold(v string) predicate.Department
- func PathGT(v string) predicate.Department
- func PathGTE(v string) predicate.Department
- func PathHasPrefix(v string) predicate.Department
- func PathHasSuffix(v string) predicate.Department
- func PathIn(vs ...string) predicate.Department
- func PathLT(v string) predicate.Department
- func PathLTE(v string) predicate.Department
- func PathNEQ(v string) predicate.Department
- func PathNotIn(vs ...string) predicate.Department
- func TenantID(v int64) predicate.Department
- func TenantIDEQ(v int64) predicate.Department
- func TenantIDIn(vs ...int64) predicate.Department
- func TenantIDNEQ(v int64) predicate.Department
- func TenantIDNotIn(vs ...int64) predicate.Department
- func UpdatedAt(v time.Time) predicate.Department
- func UpdatedAtEQ(v time.Time) predicate.Department
- func UpdatedAtGT(v time.Time) predicate.Department
- func UpdatedAtGTE(v time.Time) predicate.Department
- func UpdatedAtIn(vs ...time.Time) predicate.Department
- func UpdatedAtLT(v time.Time) predicate.Department
- func UpdatedAtLTE(v time.Time) predicate.Department
- func UpdatedAtNEQ(v time.Time) predicate.Department
- func UpdatedAtNotIn(vs ...time.Time) predicate.Department
- func UpdatedBy(v int64) predicate.Department
- func UpdatedByEQ(v int64) predicate.Department
- func UpdatedByGT(v int64) predicate.Department
- func UpdatedByGTE(v int64) predicate.Department
- func UpdatedByIn(vs ...int64) predicate.Department
- func UpdatedByIsNil() predicate.Department
- func UpdatedByLT(v int64) predicate.Department
- func UpdatedByLTE(v int64) predicate.Department
- func UpdatedByNEQ(v int64) predicate.Department
- func UpdatedByNotIn(vs ...int64) predicate.Department
- func UpdatedByNotNil() predicate.Department
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByParentID(opts ...sql.OrderTermOption) OrderOption
- func ByPath(opts ...sql.OrderTermOption) OrderOption
- func ByTenantField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByTenantID(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
- func ByUserDepartments(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByUserDepartmentsCount(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the department type in the database. Label = "department" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldTenantID holds the string denoting the tenant_id field in the database. FieldTenantID = "tenant_id" // FieldParentID holds the string denoting the parent_id field in the database. FieldParentID = "parent_id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldPath holds the string denoting the path field in the database. FieldPath = "path" // FieldAttributes holds the string denoting the attributes field in the database. FieldAttributes = "attributes" // FieldCreatedBy holds the string denoting the created_by field in the database. FieldCreatedBy = "created_by" // FieldUpdatedBy holds the string denoting the updated_by field in the database. FieldUpdatedBy = "updated_by" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // EdgeTenant holds the string denoting the tenant edge name in mutations. EdgeTenant = "tenant" // EdgeUserDepartments holds the string denoting the user_departments edge name in mutations. EdgeUserDepartments = "user_departments" // Table holds the table name of the department in the database. Table = "departments" // TenantTable is the table that holds the tenant relation/edge. TenantTable = "departments" // TenantInverseTable is the table name for the Tenant entity. // It exists in this package in order to avoid circular dependency with the "tenant" package. TenantInverseTable = "tenants" // TenantColumn is the table column denoting the tenant relation/edge. TenantColumn = "tenant_id" // UserDepartmentsTable is the table that holds the user_departments relation/edge. UserDepartmentsTable = "user_departments" // UserDepartmentsInverseTable is the table name for the UserDepartment entity. // It exists in this package in order to avoid circular dependency with the "userdepartment" package. UserDepartmentsInverseTable = "user_departments" // UserDepartmentsColumn is the table column denoting the user_departments relation/edge. UserDepartmentsColumn = "dept_id" )
Variables ¶
var ( // DefaultAttributes holds the default value on creation for the "attributes" field. DefaultAttributes map[string]interface{} // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() int64 )
var Columns = []string{ FieldID, FieldTenantID, FieldParentID, FieldName, FieldPath, FieldAttributes, FieldCreatedBy, FieldUpdatedBy, FieldCreatedAt, FieldUpdatedAt, FieldDeletedAt, }
Columns holds all SQL columns for department fields.
Functions ¶
func And ¶
func And(predicates ...predicate.Department) predicate.Department
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.Department
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.Department
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.Department
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.Department
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.Department
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.Department
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.Department
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.Department
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.Department
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedBy ¶
func CreatedBy(v int64) predicate.Department
CreatedBy applies equality check predicate on the "created_by" field. It's identical to CreatedByEQ.
func CreatedByEQ ¶
func CreatedByEQ(v int64) predicate.Department
CreatedByEQ applies the EQ predicate on the "created_by" field.
func CreatedByGT ¶
func CreatedByGT(v int64) predicate.Department
CreatedByGT applies the GT predicate on the "created_by" field.
func CreatedByGTE ¶
func CreatedByGTE(v int64) predicate.Department
CreatedByGTE applies the GTE predicate on the "created_by" field.
func CreatedByIn ¶
func CreatedByIn(vs ...int64) predicate.Department
CreatedByIn applies the In predicate on the "created_by" field.
func CreatedByIsNil ¶
func CreatedByIsNil() predicate.Department
CreatedByIsNil applies the IsNil predicate on the "created_by" field.
func CreatedByLT ¶
func CreatedByLT(v int64) predicate.Department
CreatedByLT applies the LT predicate on the "created_by" field.
func CreatedByLTE ¶
func CreatedByLTE(v int64) predicate.Department
CreatedByLTE applies the LTE predicate on the "created_by" field.
func CreatedByNEQ ¶
func CreatedByNEQ(v int64) predicate.Department
CreatedByNEQ applies the NEQ predicate on the "created_by" field.
func CreatedByNotIn ¶
func CreatedByNotIn(vs ...int64) predicate.Department
CreatedByNotIn applies the NotIn predicate on the "created_by" field.
func CreatedByNotNil ¶
func CreatedByNotNil() predicate.Department
CreatedByNotNil applies the NotNil predicate on the "created_by" field.
func DeletedAt ¶
func DeletedAt(v time.Time) predicate.Department
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
func DeletedAtEQ(v time.Time) predicate.Department
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
func DeletedAtGT(v time.Time) predicate.Department
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
func DeletedAtGTE(v time.Time) predicate.Department
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
func DeletedAtIn(vs ...time.Time) predicate.Department
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
func DeletedAtIsNil() predicate.Department
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
func DeletedAtLT(v time.Time) predicate.Department
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
func DeletedAtLTE(v time.Time) predicate.Department
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
func DeletedAtNEQ(v time.Time) predicate.Department
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
func DeletedAtNotIn(vs ...time.Time) predicate.Department
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
func DeletedAtNotNil() predicate.Department
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func HasTenant ¶
func HasTenant() predicate.Department
HasTenant applies the HasEdge predicate on the "tenant" edge.
func HasTenantWith ¶
func HasTenantWith(preds ...predicate.Tenant) predicate.Department
HasTenantWith applies the HasEdge predicate on the "tenant" edge with a given conditions (other predicates).
func HasUserDepartments ¶
func HasUserDepartments() predicate.Department
HasUserDepartments applies the HasEdge predicate on the "user_departments" edge.
func HasUserDepartmentsWith ¶
func HasUserDepartmentsWith(preds ...predicate.UserDepartment) predicate.Department
HasUserDepartmentsWith applies the HasEdge predicate on the "user_departments" edge with a given conditions (other predicates).
func IDGTE ¶
func IDGTE(id int64) predicate.Department
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int64) predicate.Department
IDIn applies the In predicate on the ID field.
func IDLTE ¶
func IDLTE(id int64) predicate.Department
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int64) predicate.Department
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int64) predicate.Department
IDNotIn applies the NotIn predicate on the ID field.
func Name ¶
func Name(v string) predicate.Department
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.Department
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.Department
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.Department
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.Department
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.Department
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.Department
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.Department
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.Department
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.Department
NameIn applies the In predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.Department
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.Department
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.Department
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.Department
NameNotIn applies the NotIn predicate on the "name" field.
func Not ¶
func Not(p predicate.Department) predicate.Department
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.Department) predicate.Department
Or groups predicates with the OR operator between them.
func ParentID ¶
func ParentID(v int64) predicate.Department
ParentID applies equality check predicate on the "parent_id" field. It's identical to ParentIDEQ.
func ParentIDEQ ¶
func ParentIDEQ(v int64) predicate.Department
ParentIDEQ applies the EQ predicate on the "parent_id" field.
func ParentIDGT ¶
func ParentIDGT(v int64) predicate.Department
ParentIDGT applies the GT predicate on the "parent_id" field.
func ParentIDGTE ¶
func ParentIDGTE(v int64) predicate.Department
ParentIDGTE applies the GTE predicate on the "parent_id" field.
func ParentIDIn ¶
func ParentIDIn(vs ...int64) predicate.Department
ParentIDIn applies the In predicate on the "parent_id" field.
func ParentIDLT ¶
func ParentIDLT(v int64) predicate.Department
ParentIDLT applies the LT predicate on the "parent_id" field.
func ParentIDLTE ¶
func ParentIDLTE(v int64) predicate.Department
ParentIDLTE applies the LTE predicate on the "parent_id" field.
func ParentIDNEQ ¶
func ParentIDNEQ(v int64) predicate.Department
ParentIDNEQ applies the NEQ predicate on the "parent_id" field.
func ParentIDNotIn ¶
func ParentIDNotIn(vs ...int64) predicate.Department
ParentIDNotIn applies the NotIn predicate on the "parent_id" field.
func Path ¶
func Path(v string) predicate.Department
Path applies equality check predicate on the "path" field. It's identical to PathEQ.
func PathContains ¶
func PathContains(v string) predicate.Department
PathContains applies the Contains predicate on the "path" field.
func PathContainsFold ¶
func PathContainsFold(v string) predicate.Department
PathContainsFold applies the ContainsFold predicate on the "path" field.
func PathEQ ¶
func PathEQ(v string) predicate.Department
PathEQ applies the EQ predicate on the "path" field.
func PathEqualFold ¶
func PathEqualFold(v string) predicate.Department
PathEqualFold applies the EqualFold predicate on the "path" field.
func PathGT ¶
func PathGT(v string) predicate.Department
PathGT applies the GT predicate on the "path" field.
func PathGTE ¶
func PathGTE(v string) predicate.Department
PathGTE applies the GTE predicate on the "path" field.
func PathHasPrefix ¶
func PathHasPrefix(v string) predicate.Department
PathHasPrefix applies the HasPrefix predicate on the "path" field.
func PathHasSuffix ¶
func PathHasSuffix(v string) predicate.Department
PathHasSuffix applies the HasSuffix predicate on the "path" field.
func PathIn ¶
func PathIn(vs ...string) predicate.Department
PathIn applies the In predicate on the "path" field.
func PathLT ¶
func PathLT(v string) predicate.Department
PathLT applies the LT predicate on the "path" field.
func PathLTE ¶
func PathLTE(v string) predicate.Department
PathLTE applies the LTE predicate on the "path" field.
func PathNEQ ¶
func PathNEQ(v string) predicate.Department
PathNEQ applies the NEQ predicate on the "path" field.
func PathNotIn ¶
func PathNotIn(vs ...string) predicate.Department
PathNotIn applies the NotIn predicate on the "path" field.
func TenantID ¶
func TenantID(v int64) predicate.Department
TenantID applies equality check predicate on the "tenant_id" field. It's identical to TenantIDEQ.
func TenantIDEQ ¶
func TenantIDEQ(v int64) predicate.Department
TenantIDEQ applies the EQ predicate on the "tenant_id" field.
func TenantIDIn ¶
func TenantIDIn(vs ...int64) predicate.Department
TenantIDIn applies the In predicate on the "tenant_id" field.
func TenantIDNEQ ¶
func TenantIDNEQ(v int64) predicate.Department
TenantIDNEQ applies the NEQ predicate on the "tenant_id" field.
func TenantIDNotIn ¶
func TenantIDNotIn(vs ...int64) predicate.Department
TenantIDNotIn applies the NotIn predicate on the "tenant_id" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.Department
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.Department
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.Department
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.Department
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.Department
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.Department
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.Department
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.Department
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.Department
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedBy ¶
func UpdatedBy(v int64) predicate.Department
UpdatedBy applies equality check predicate on the "updated_by" field. It's identical to UpdatedByEQ.
func UpdatedByEQ ¶
func UpdatedByEQ(v int64) predicate.Department
UpdatedByEQ applies the EQ predicate on the "updated_by" field.
func UpdatedByGT ¶
func UpdatedByGT(v int64) predicate.Department
UpdatedByGT applies the GT predicate on the "updated_by" field.
func UpdatedByGTE ¶
func UpdatedByGTE(v int64) predicate.Department
UpdatedByGTE applies the GTE predicate on the "updated_by" field.
func UpdatedByIn ¶
func UpdatedByIn(vs ...int64) predicate.Department
UpdatedByIn applies the In predicate on the "updated_by" field.
func UpdatedByIsNil ¶
func UpdatedByIsNil() predicate.Department
UpdatedByIsNil applies the IsNil predicate on the "updated_by" field.
func UpdatedByLT ¶
func UpdatedByLT(v int64) predicate.Department
UpdatedByLT applies the LT predicate on the "updated_by" field.
func UpdatedByLTE ¶
func UpdatedByLTE(v int64) predicate.Department
UpdatedByLTE applies the LTE predicate on the "updated_by" field.
func UpdatedByNEQ ¶
func UpdatedByNEQ(v int64) predicate.Department
UpdatedByNEQ applies the NEQ predicate on the "updated_by" field.
func UpdatedByNotIn ¶
func UpdatedByNotIn(vs ...int64) predicate.Department
UpdatedByNotIn applies the NotIn predicate on the "updated_by" field.
func UpdatedByNotNil ¶
func UpdatedByNotNil() predicate.Department
UpdatedByNotNil applies the NotNil predicate on the "updated_by" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Department queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedBy ¶
func ByCreatedBy(opts ...sql.OrderTermOption) OrderOption
ByCreatedBy orders the results by the created_by field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByParentID ¶
func ByParentID(opts ...sql.OrderTermOption) OrderOption
ByParentID orders the results by the parent_id field.
func ByPath ¶
func ByPath(opts ...sql.OrderTermOption) OrderOption
ByPath orders the results by the path field.
func ByTenantField ¶
func ByTenantField(field string, opts ...sql.OrderTermOption) OrderOption
ByTenantField orders the results by tenant field.
func ByTenantID ¶
func ByTenantID(opts ...sql.OrderTermOption) OrderOption
ByTenantID orders the results by the tenant_id field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedBy ¶
func ByUpdatedBy(opts ...sql.OrderTermOption) OrderOption
ByUpdatedBy orders the results by the updated_by field.
func ByUserDepartments ¶
func ByUserDepartments(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByUserDepartments orders the results by user_departments terms.
func ByUserDepartmentsCount ¶
func ByUserDepartmentsCount(opts ...sql.OrderTermOption) OrderOption
ByUserDepartmentsCount orders the results by user_departments count.