Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.UserTenant) predicate.UserTenant
- func HasTenant() predicate.UserTenant
- func HasTenantWith(preds ...predicate.Tenant) predicate.UserTenant
- func HasUser() predicate.UserTenant
- func HasUserWith(preds ...predicate.User) predicate.UserTenant
- func ID(id int) predicate.UserTenant
- func IDEQ(id int) predicate.UserTenant
- func IDGT(id int) predicate.UserTenant
- func IDGTE(id int) predicate.UserTenant
- func IDIn(ids ...int) predicate.UserTenant
- func IDLT(id int) predicate.UserTenant
- func IDLTE(id int) predicate.UserTenant
- func IDNEQ(id int) predicate.UserTenant
- func IDNotIn(ids ...int) predicate.UserTenant
- func Not(p predicate.UserTenant) predicate.UserTenant
- func Or(predicates ...predicate.UserTenant) predicate.UserTenant
- func RoleLabelsIsNil() predicate.UserTenant
- func RoleLabelsNotNil() predicate.UserTenant
- func TenantID(v int64) predicate.UserTenant
- func TenantIDEQ(v int64) predicate.UserTenant
- func TenantIDIn(vs ...int64) predicate.UserTenant
- func TenantIDNEQ(v int64) predicate.UserTenant
- func TenantIDNotIn(vs ...int64) predicate.UserTenant
- func UserID(v int64) predicate.UserTenant
- func UserIDEQ(v int64) predicate.UserTenant
- func UserIDIn(vs ...int64) predicate.UserTenant
- func UserIDNEQ(v int64) predicate.UserTenant
- func UserIDNotIn(vs ...int64) predicate.UserTenant
- func ValidColumn(column string) bool
- type OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByTenantField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByTenantID(opts ...sql.OrderTermOption) OrderOption
- func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByUserID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the usertenant type in the database. Label = "user_tenant" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldTenantID holds the string denoting the tenant_id field in the database. FieldTenantID = "tenant_id" // FieldRoleLabels holds the string denoting the role_labels field in the database. FieldRoleLabels = "role_labels" // EdgeUser holds the string denoting the user edge name in mutations. EdgeUser = "user" // EdgeTenant holds the string denoting the tenant edge name in mutations. EdgeTenant = "tenant" // Table holds the table name of the usertenant in the database. Table = "user_tenants" // UserTable is the table that holds the user relation/edge. UserTable = "user_tenants" // UserInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. UserInverseTable = "users" // UserColumn is the table column denoting the user relation/edge. UserColumn = "user_id" // TenantTable is the table that holds the tenant relation/edge. TenantTable = "user_tenants" // TenantInverseTable is the table name for the Tenant entity. // It exists in this package in order to avoid circular dependency with the "tenant" package. TenantInverseTable = "tenants" // TenantColumn is the table column denoting the tenant relation/edge. TenantColumn = "tenant_id" )
Variables ¶
var Columns = []string{ FieldID, FieldUserID, FieldTenantID, FieldRoleLabels, }
Columns holds all SQL columns for usertenant fields.
Functions ¶
func And ¶
func And(predicates ...predicate.UserTenant) predicate.UserTenant
And groups predicates with the AND operator between them.
func HasTenant ¶
func HasTenant() predicate.UserTenant
HasTenant applies the HasEdge predicate on the "tenant" edge.
func HasTenantWith ¶
func HasTenantWith(preds ...predicate.Tenant) predicate.UserTenant
HasTenantWith applies the HasEdge predicate on the "tenant" edge with a given conditions (other predicates).
func HasUser ¶
func HasUser() predicate.UserTenant
HasUser applies the HasEdge predicate on the "user" edge.
func HasUserWith ¶
func HasUserWith(preds ...predicate.User) predicate.UserTenant
HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).
func IDGTE ¶
func IDGTE(id int) predicate.UserTenant
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.UserTenant
IDIn applies the In predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.UserTenant
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.UserTenant
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.UserTenant
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.UserTenant) predicate.UserTenant
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.UserTenant) predicate.UserTenant
Or groups predicates with the OR operator between them.
func RoleLabelsIsNil ¶
func RoleLabelsIsNil() predicate.UserTenant
RoleLabelsIsNil applies the IsNil predicate on the "role_labels" field.
func RoleLabelsNotNil ¶
func RoleLabelsNotNil() predicate.UserTenant
RoleLabelsNotNil applies the NotNil predicate on the "role_labels" field.
func TenantID ¶
func TenantID(v int64) predicate.UserTenant
TenantID applies equality check predicate on the "tenant_id" field. It's identical to TenantIDEQ.
func TenantIDEQ ¶
func TenantIDEQ(v int64) predicate.UserTenant
TenantIDEQ applies the EQ predicate on the "tenant_id" field.
func TenantIDIn ¶
func TenantIDIn(vs ...int64) predicate.UserTenant
TenantIDIn applies the In predicate on the "tenant_id" field.
func TenantIDNEQ ¶
func TenantIDNEQ(v int64) predicate.UserTenant
TenantIDNEQ applies the NEQ predicate on the "tenant_id" field.
func TenantIDNotIn ¶
func TenantIDNotIn(vs ...int64) predicate.UserTenant
TenantIDNotIn applies the NotIn predicate on the "tenant_id" field.
func UserID ¶
func UserID(v int64) predicate.UserTenant
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDEQ ¶
func UserIDEQ(v int64) predicate.UserTenant
UserIDEQ applies the EQ predicate on the "user_id" field.
func UserIDIn ¶
func UserIDIn(vs ...int64) predicate.UserTenant
UserIDIn applies the In predicate on the "user_id" field.
func UserIDNEQ ¶
func UserIDNEQ(v int64) predicate.UserTenant
UserIDNEQ applies the NEQ predicate on the "user_id" field.
func UserIDNotIn ¶
func UserIDNotIn(vs ...int64) predicate.UserTenant
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the UserTenant queries.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByTenantField ¶
func ByTenantField(field string, opts ...sql.OrderTermOption) OrderOption
ByTenantField orders the results by tenant field.
func ByTenantID ¶
func ByTenantID(opts ...sql.OrderTermOption) OrderOption
ByTenantID orders the results by the tenant_id field.
func ByUserField ¶
func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
ByUserField orders the results by user field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.